# Generated by Alan Viars

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djmongo_read', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customipauthreadapi',
            name='output_format',
            field=models.CharField(choices=[('json', 'JSON'), ('ndjson', 'NDJSON'), ('csv', 'Comma Separated Value (.csv)'), ('txt', 'Tab-Delimited'), ('html', 'HTML')], default='json', max_length=6)
        ),

        migrations.AlterField(
            model_name='customoauth2readapi',
            name='output_format',
            field=models.CharField(choices=[('json', 'JSON'), ('ndjson', 'NDJSON'), ('csv', 'Comma Separated Value (.csv)'), ('txt', 'Tab-Delimited'), ('html', 'HTML')], default='json', max_length=6)
        ),
        migrations.AlterField(
            model_name='customhttpauthreadapi',
            name='output_format',
            field=models.CharField(choices=[('json', 'JSON'), ('ndjson', 'NDJSON'), ('csv', 'Comma Separated Value (.csv)'), ('txt', 'Tab-Delimited'), ('html', 'HTML')], default='json', max_length=6)
        ),
        migrations.AlterField(
            model_name='custompublicreadapi',
            name='output_format',
            field=models.CharField(choices=[('json', 'JSON'), ('ndjson', 'NDJSON'), ('csv', 'Comma Separated Value (.csv)'), ('txt', 'Tab-Delimited'), ('html', 'HTML')], default='json', max_length=6)
        ),
    ]
